@@ -4,7 +4,7 @@ from ._distutils import _modified
 
 
 def __getattr__(name):
-    if name not in ['newer_pairwise_group']:
+    if name not in ['newer_group', 'newer_pairwise_group']:
         raise AttributeError(name)
     warnings.warn(
         "dep_util is Deprecated. Use functions from setuptools.modified instead.",
